@@ -131,7 +131,7 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
     # Check if phone_promptresponse file exists for this date
     csv_path = list(glob(os.path.join(date_folder_path, 'phone_promptresponse_clean*.csv')))
     if len(csv_path) == 0:
-        print(csv_path)
+        print(date_folder_path)
         sys.exit("No intermediate promptresponse csv file on {}".format(date_in_study))
 
     # read and filter prompt type
